@@ -1,20 +1,20 @@
 #include <UgApp-base.h>
 #include <UgMarkup.h>
-#include <UgData-download.h>
+#include <UgetData.h>
 
 void test_conf ()
 {
 	UgMarkup*		markup;
 	UgDataset*		dataset;
-	UgProgress*		progress;
-	UgDataHttp*		http;
-	UgDataFtp*		ftp;
+	UgetProgress*		progress;
+	UgetHttp*		http;
+	UgetFtp*		ftp;
 
 	markup		= ug_markup_new ();
 	dataset		= ug_dataset_new ();
-	progress	= ug_dataset_realloc (dataset, UG_PROGRESS_I, 0);
-	http		= ug_dataset_realloc (dataset, UG_DATA_HTTP_I, 0);
-	ftp			= ug_dataset_realloc (dataset, UG_DATA_FTP_I, 0);
+	progress	= ug_dataset_realloc (dataset, UgetProgressInfo, 0);
+	http		= ug_dataset_realloc (dataset, UgetHttpInfo, 0);
+	ftp			= ug_dataset_realloc (dataset, UgetFtpInfo, 0);
 
 	progress->total = 1484889;
 	http->redirection_limit = 10;
@@ -30,9 +30,9 @@ void test_conf ()
 
 	dataset = ug_dataset_new ();
 	if (ug_markup_parse ("test.ug.xml", &ug_data_parser, dataset)) {
-		progress	= ug_dataset_realloc (dataset, UG_PROGRESS_I, 0);
-		http		= ug_dataset_realloc (dataset, UG_DATA_HTTP_I, 0);
-		ftp			= ug_dataset_realloc (dataset, UG_DATA_FTP_I, 0);
+		progress	= ug_dataset_realloc (dataset, UgetProgressInfo, 0);
+		http		= ug_dataset_realloc (dataset, UgetHttpInfo, 0);
+		ftp			= ug_dataset_realloc (dataset, UgetFtpInfo, 0);
 	}
 
 	ug_dataset_unref (dataset);
