@@ -1,6 +1,6 @@
 static const char	uget_license[] =
 {
-" Copyright (C) 2005-2013 by C.H. Huang"								"\n"
+" Copyright (C) 2005-2014 by C.H. Huang"								"\n"
 " plushuang.tw@gmail.com"												"\n"
 																		"\n"
 "This library is free software; you can redistribute it and/or"			"\n"
@@ -42,7 +42,7 @@ static const char	uget_license[] =
 // uglib
 #include <UgHtml.h>
 #include <UgUtils.h>
-#include <UgData-download.h>
+#include <UgetData.h>
 #include <UgDownloadDialog.h>
 #include <UgCategoryDialog.h>
 #include <UgSettingDialog.h>
@@ -50,7 +50,7 @@ static const char	uget_license[] =
 
 #include <glib/gi18n.h>
 
-#define	UGET_URL_WEBSITE	"http://uGet.visuex.com/"
+#define	UGET_URL_WEBSITE	"http://ugetdm.com/"
 
 // static data
 static const gchar*	uget_authors[] = { "C.H. Huang  (\xE9\xBB\x83\xE6\xAD\xA3\xE9\x9B\x84)", NULL };
@@ -64,7 +64,7 @@ static const gchar*	uget_artists[] =
 };
 static const gchar*	uget_version   = UG_APP_GTK_VERSION;
 static const gchar*	uget_comments  = N_("Download Manager");
-static const gchar*	uget_copyright = "Copyright (C) 2005-2013 C.H. Huang";
+static const gchar*	uget_copyright = "Copyright (C) 2005-2014 C.H. Huang";
 static const gchar*	translator_credits = N_("translator-credits");
 
 // static functions
@@ -197,7 +197,7 @@ static void	on_config_category (GtkWidget* widget, UgAppGtk* app)
 //
 static void	ug_app_setup_download_dialog (UgAppGtk* app, UgDownloadDialog* ddialog)
 {
-	UgDataCommon*	common;
+	UgetCommon*	common;
 	GtkTreePath*	path;
 	GtkTreeModel*	model;
 
@@ -213,7 +213,7 @@ static void	ug_app_setup_download_dialog (UgAppGtk* app, UgDownloadDialog* ddial
 			gtk_tree_path_free (path);
 		}
 
-		common = ug_dataset_realloc (app->last.download, UG_DATA_COMMON_I, 0);
+		common = ug_dataset_realloc (app->last.download, UgetCommonInfo, 0);
 		if (common && common->file) {
 			g_free (common->file);
 			common->file = NULL;
@@ -447,7 +447,7 @@ static void	on_create_metalink (GtkWidget* widget, UgAppGtk* app)
 static void	on_delete_download (GtkWidget* widget, UgAppGtk* app)
 {
 	UgDownloadWidget*	dwidget;
-	UgRelation*			relation;
+	UgetRelation*			relation;
 	GList*				list;
 	GList*				link;
 	// check shift key status
@@ -492,7 +492,7 @@ static void	on_delete_download (GtkWidget* widget, UgAppGtk* app)
 static void	on_delete_download_file_response (GtkWidget* widget, gint response_id, UgAppGtk* app)
 {
 	UgDownloadWidget*	dwidget;
-	UgDataCommon*		common;
+	UgetCommon*		common;
 	gchar*				path;
 	GList*				list;
 	GList*				link;
@@ -544,7 +544,7 @@ static void	on_delete_download_file (GtkWidget* widget, UgAppGtk* app)
 static void	on_open_download_file (GtkWidget* widget, UgAppGtk* app)
 {
 	UgDownloadWidget*	dwidget;
-	UgDataCommon*		common;
+	UgetCommon*		common;
 	UgDataset*			dataset;
 	GtkWidget*			dialog;
 	gchar*				string;
@@ -553,7 +553,7 @@ static void	on_open_download_file (GtkWidget* widget, UgAppGtk* app)
 	dataset = ug_download_widget_get_cursor (dwidget);
 	if (dataset == NULL)
 		return;
-	common = ug_dataset_get (dataset, UG_DATA_COMMON_I, 0);
+	common = ug_dataset_get (dataset, UgetCommonInfo, 0);
 	if (common->folder == NULL || common->file == NULL)
 		return;
 
@@ -575,7 +575,7 @@ static void	on_open_download_file (GtkWidget* widget, UgAppGtk* app)
 static void	on_open_download_folder (GtkWidget* widget, UgAppGtk* app)
 {
 	UgDownloadWidget*	dwidget;
-	UgDataCommon*		common;
+	UgetCommon*		common;
 	UgDataset*			dataset;
 	GtkWidget*			dialog;
 	gchar*				string;
@@ -584,7 +584,7 @@ static void	on_open_download_folder (GtkWidget* widget, UgAppGtk* app)
 	dataset = ug_download_widget_get_cursor (dwidget);
 	if (dataset == NULL)
 		return;
-	common = ug_dataset_get (dataset, UG_DATA_COMMON_I, 0);
+	common = ug_dataset_get (dataset, UgetCommonInfo, 0);
 	if (common->folder == NULL)
 		return;
 
@@ -694,7 +694,7 @@ static void	on_config_download (GtkWidget* widget, UgAppGtk* app)
 static void	on_set_download_force_start (GtkWidget* widget, UgAppGtk* app)
 {
 	UgDownloadWidget*	dwidget;
-	UgRelation*			relation;
+	UgetRelation*			relation;
 	GList*				list;
 	GList*				link;
 
@@ -715,7 +715,7 @@ static void	on_set_download_force_start (GtkWidget* widget, UgAppGtk* app)
 static void	on_set_download_runnable (GtkWidget* widget, UgAppGtk* app)
 {
 	UgDownloadWidget*	dwidget;
-	UgRelation*			relation;
+	UgetRelation*			relation;
 	GList*				list;
 	GList*				link;
 
@@ -737,7 +737,7 @@ static void	on_set_download_runnable (GtkWidget* widget, UgAppGtk* app)
 static void	on_set_download_to_pause (GtkWidget* widget, UgAppGtk* app)
 {
 	UgDownloadWidget*	dwidget;
-	UgRelation*			relation;
+	UgetRelation*			relation;
 	GList*				list;
 	GList*				link;
 
@@ -1309,13 +1309,45 @@ void	on_change_visible_column (GtkWidget* widget, UgAppGtk* app)
 // ----------------------------------------------------------------------------
 // UgHelpMenu
 //
+void	on_help_online (GtkWidget* widget, UgAppGtk* app)
+{
+	ug_launch_uri ("http://ugetdm.com/help");
+}
+
+void	on_documentation (GtkWidget* widget, UgAppGtk* app)
+{
+	ug_launch_uri ("http://ugetdm.com/documentation");
+}
+
+void    on_support_forum (GtkWidget* widget, UgAppGtk* app)
+{
+	ug_launch_uri ("http://ugetdm.com/forum/");
+}
+
+void    on_submit_feedback (GtkWidget* widget, UgAppGtk* app)
+{
+	ug_launch_uri ("http://ugetdm.com/feedback");
+}
+
+void    on_report_bug (GtkWidget* widget, UgAppGtk* app)
+{
+	ug_launch_uri ("http://ugetdm.com/reportbug");
+}
+
+void    on_check_updates (GtkWidget* widget, UgAppGtk* app)
+{
+	ug_launch_uri ("http://ugetdm.com/versioncheck?v=" PACKAGE_VERSION);
+}
+
 void	on_about (GtkWidget* widget, UgAppGtk* app)
 {
-	GtkImage* img;
-	char* path;
+	GtkDialog* adialog;
+	GdkPixbuf* pixbuf;
+	char*      path;
 
-	path = g_build_filename (ug_get_data_dir (), "pixmaps", "uget", "logo.png", NULL);
-	img = (GtkImage*) gtk_image_new_from_file (path);
+	path = g_build_filename (
+			ug_get_data_dir (), "pixmaps", "uget", "logo.png", NULL);
+	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 	g_free (path);
 
 //	if (gtk_widget_get_visible ((GtkWidget*) app->window.self) == FALSE) {
@@ -1323,9 +1355,12 @@ void	on_about (GtkWidget* widget, UgAppGtk* app)
 //		gtk_widget_show ((GtkWidget*) app->window.self);
 //	}
 
-	gtk_show_about_dialog (app->window.self,
+	adialog = (GtkDialog*) gtk_about_dialog_new ();
+	gtk_window_set_transient_for ((GtkWindow*) adialog, app->window.self);
+	gtk_dialog_set_default_response (adialog, GTK_RESPONSE_CANCEL);
+	g_object_set (adialog,
 //			"logo-icon-name", UG_APP_GTK_APP_ICON_NAME,
-			"logo", gtk_image_get_pixbuf (img),
+			"logo", pixbuf,
 			"program-name", UG_APP_GTK_NAME,
 			"version", uget_version,
 			"comments", gettext (uget_comments),
@@ -1341,7 +1376,35 @@ void	on_about (GtkWidget* widget, UgAppGtk* app)
 			"translator-credits", gettext (translator_credits),
 			NULL);
 
-	g_object_unref (img);
+	if (app->update_info.ready) {
+		GtkScrolledWindow* scrolled;
+		GtkTextBuffer* tbuf;
+		GtkWidget* textview;
+		GtkBox* box;
+
+		textview = gtk_text_view_new ();
+		tbuf = gtk_text_view_get_buffer ((GtkTextView*) textview);
+		gtk_text_buffer_set_text (tbuf, app->update_info.text->str, -1);
+
+		scrolled = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
+		gtk_widget_set_size_request ((GtkWidget*) scrolled, 200, 120);
+		gtk_scrolled_window_set_shadow_type (scrolled, GTK_SHADOW_IN);
+		gtk_scrolled_window_set_policy (scrolled,
+				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		gtk_container_add (GTK_CONTAINER (scrolled), textview);
+		gtk_widget_show_all ((GtkWidget*) scrolled);
+
+		box = (GtkBox*) gtk_dialog_get_content_area (adialog);
+		gtk_box_pack_end (box, (GtkWidget*) scrolled, TRUE, TRUE, 2);
+	}
+
+	// Close button - GTK_RESPONSE_CANCEL
+	g_signal_connect (adialog, "response",
+			G_CALLBACK (gtk_widget_destroy), NULL);
+
+	gtk_dialog_run (adialog);
+	if (pixbuf)
+		g_object_unref (pixbuf);
 }
 
 // ----------------------------------------------------------------------------
@@ -1937,6 +2000,18 @@ static void ug_menubar_init_callback (struct UgMenubar* menubar, UgAppGtk* app)
 
 	// ----------------------------------------------------
 	// UgHelpMenu
+	g_signal_connect (menubar->help.help_online, "activate",
+			G_CALLBACK (on_help_online), app);
+	g_signal_connect (menubar->help.documentation, "activate",
+			G_CALLBACK (on_documentation), app);
+	g_signal_connect (menubar->help.support_forum, "activate",
+			G_CALLBACK (on_support_forum), app);
+	g_signal_connect (menubar->help.submit_feedback, "activate",
+			G_CALLBACK (on_submit_feedback), app);
+	g_signal_connect (menubar->help.check_updates, "activate",
+			G_CALLBACK (on_check_updates), app);
+	g_signal_connect (menubar->help.report_bug, "activate",
+			G_CALLBACK (on_report_bug), app);
 	g_signal_connect (menubar->help.about_uget, "activate",
 			G_CALLBACK (on_about), app);
 }
