@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2013 by C.H. Huang
+ *   Copyright (C) 2005-2014 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -38,8 +38,9 @@
 #include <UgUtils.h>
 #include <UgString.h>
 #include <UgRegistry.h>
-#include <UgData-download.h>
+#include <UgetData.h>
 #include <UgApp-gtk.h>
+#include <curl/curl.h>
 
 #include <glib/gi18n.h>
 
@@ -76,7 +77,7 @@ static void ug_app_update_config_dir (void)
 void	ug_app_init (UgAppGtk* app)
 {
 	UgCategory*		category;
-	UgDataCommon*	common;
+	UgetCommon*	common;
 
 	ug_running_init (&app->running);
 	// upgrade from Uget 1.6
@@ -98,7 +99,7 @@ void	ug_app_init (UgAppGtk* app)
 	if (ug_category_widget_n_category (&app->cwidget) == 0) {
 		category = ug_category_new_with_gtk (app->cwidget.primary.category);
 		category->name = g_strdup ("Home");
-		common = ug_dataset_alloc_front (category->defaults, UG_DATA_COMMON_I);
+		common = ug_dataset_alloc_front (category->defaults, UgetCommonInfo);
 		common->folder = g_strdup (g_get_home_dir ());
 		ug_category_widget_append (&app->cwidget, category);
 	}
@@ -109,6 +110,8 @@ void	ug_app_init (UgAppGtk* app)
 	// initialize aria2
 	ug_app_aria2_init (app);
 	ug_app_aria2_setup (app);
+	// get update info
+	ug_app_get_update_info (app);
 
 	ug_app_menubar_sync_category (app, TRUE);
 	ug_category_view_set_cursor (app->cwidget.primary.view, 0, -1);
@@ -137,6 +140,8 @@ void	ug_app_quit (UgAppGtk* app)
 	ug_trayicon_set_visible (&app->trayicon, FALSE);
 	// hide window
 	gtk_widget_hide (GTK_WIDGET (app->window.self));
+	// clear update info
+	ug_app_clear_update_info (app);
 	// aria2
 	ug_app_aria2_shutdown (app);
 	// This will quit gtk_main() in main()
@@ -232,6 +237,8 @@ void	ug_app_set_setting (UgAppGtk* app, UgSetting* setting)
 			setting->window.category);
 	gtk_widget_set_visible (app->summary.self,
 			setting->window.summary);
+	gtk_widget_set_visible (app->banner.self,
+			setting->window.banner);
 	// Summary
 	app->summary.visible.name     = setting->summary.name;
 	app->summary.visible.folder   = setting->summary.folder;
@@ -363,8 +370,64 @@ void	ug_app_get_setting (UgAppGtk* app, UgSetting* setting)
 		app->setting.download_column.sort.nth   = app->cwidget.sort.nth;
 		app->setting.download_column.sort.order = app->cwidget.sort.order;
 	}
+
+	// banner
+	setting->window.banner = gtk_widget_get_visible (app->banner.self);
 }
 
+// ------------------------------------
+
+static size_t  write_update_info (void *ptr, size_t size, size_t nmemb, GString* buf)
+{
+	if (buf->len > 4096)
+		return 0;
+	g_string_append_len (buf, ptr, size * nmemb);
+	return nmemb;
+}
+
+static void  get_update_info_thread (UgAppGtk* app)
+{
+	CURL*		curl;
+	CURLcode	res;
+	long		response_code = 0;
+
+	curl = curl_easy_init();
+	curl_easy_setopt (curl, CURLOPT_WRITEFUNCTION,
+			(curl_write_callback) write_update_info);
+	curl_easy_setopt (curl, CURLOPT_WRITEDATA, app->update_info.text);
+	curl_easy_setopt (curl, CURLOPT_URL, "http://ugetdm.com/versioncheck?v=" PACKAGE_VERSION);
+	curl_easy_setopt (curl, CURLOPT_NOSIGNAL, 1);
+	res = curl_easy_perform (curl);
+	curl_easy_getinfo (curl, CURLINFO_RESPONSE_CODE, &response_code);
+	curl_easy_cleanup (curl);
+
+	if (res == CURLE_OK && response_code < 400)
+		app->update_info.ready = TRUE;
+	app->update_info.thread = NULL;
+}
+
+void ug_app_get_update_info (UgAppGtk* app)
+{
+	if (app->update_info.thread == NULL) {
+		if (app->update_info.text == NULL)
+			app->update_info.text = g_string_sized_new (2048);
+		g_string_set_size (app->update_info.text, 0);
+		app->update_info.ready = FALSE;
+		app->update_info.thread = g_thread_new ("get update info",
+				(GThreadFunc) get_update_info_thread, app);
+		g_thread_unref (app->update_info.thread);
+	}
+}
+
+void  ug_app_clear_update_info (UgAppGtk* app)
+{
+	if (app->update_info.thread == NULL) {
+		if (app->update_info.text)
+			g_string_free (app->update_info.text, TRUE);
+		app->update_info.text = NULL;
+		app->update_info.ready = FALSE;
+	}
+}
 
 // -------------------------------------------------------
 // UgClipboard
@@ -1006,6 +1069,7 @@ void	ug_app_decide_download_sensitive (UgAppGtk* app)
 		gtk_widget_set_sensitive (app->menubar.download.open_folder, sensitive);
 		gtk_widget_set_sensitive (app->menubar.download.delete, sensitive);
 		gtk_widget_set_sensitive (app->menubar.download.delete_file, sensitive);
+		gtk_widget_set_sensitive (app->menubar.download.force_start, sensitive);
 		gtk_widget_set_sensitive (app->menubar.download.runnable, sensitive);
 		gtk_widget_set_sensitive (app->menubar.download.pause, sensitive);
 		gtk_widget_set_sensitive (app->menubar.download.move_to.item, sensitive);
