@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2013 by C.H. Huang
+ *   Copyright (C) 2005-2014 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@
  */
 
 #include <UgDownloadForm.h>
-#include <UgData-download.h>
+#include <UgetData.h>
 #include <UgCategory-gtk.h>
 #include <UgUri.h>
 #include <UgUtils.h>
@@ -71,9 +71,9 @@ void	ug_download_form_init (UgDownloadForm* dform, UgProxyForm* proxy, GtkWindow
 	dform->changed.cookie   = FALSE;
 	dform->changed.post     = FALSE;
 	dform->changed.agent    = FALSE;
-	dform->changed.timestamp= FALSE;
 	dform->changed.retry    = FALSE;
 	dform->changed.delay    = FALSE;
+	dform->changed.retrieve_timestamp= FALSE;
 	dform->parent = parent;
 
 	ug_download_form_init_page1 (dform, proxy);
@@ -482,16 +482,16 @@ static void ug_download_form_decide_sensitive (UgDownloadForm* dform)
 
 void	ug_download_form_get  (UgDownloadForm* dform, UgDataset* dataset)
 {
-	UgDataCommon*	common;
-	UgDataHttp*		http;
-	UgRelation*		relation;
-	UgUriFull		urifull;
-	const gchar*	text;
-	gint			number;
+	UgetCommon*   common;
+	UgetHttp*     http;
+	UgetRelation* relation;
+	UgUri         uuri;
+	const gchar*  text;
+	gint          number;
 
 	// ------------------------------------------
-	// UgDataCommon
-	common = ug_dataset_realloc (dataset, UG_DATA_COMMON_I, 0);
+	// UgetCommon
+	common = ug_dataset_realloc (dataset, UgetCommonInfo, 0);
 	// folder
 	text = gtk_entry_get_text ((GtkEntry*)dform->folder_entry);
 	ug_str_set (&common->folder, text, -1);
@@ -524,30 +524,30 @@ void	ug_download_form_get  (UgDownloadForm* dform, UgDataset* dataset)
 		ug_str_set (&common->mirrors, gtk_entry_get_text ((GtkEntry*)dform->mirrors_entry), -1);
 		ug_str_set (&common->file, gtk_entry_get_text ((GtkEntry*)dform->file_entry), -1);
 		if (common->url) {
-			ug_uri_full_init (&urifull, common->url);
+			ug_uri_init (&uuri, common->url);
 			// set user
-			text = ug_uri_full_get_user (&urifull);
+			text = ug_uri_get_user (&uuri);
 			if (text) {
 				g_free (common->user);
 				common->user = (gchar*) text;
 			}
 			// set password
-			text = ug_uri_full_get_password (&urifull);
+			text = ug_uri_get_password (&uuri);
 			if (text) {
 				g_free (common->password);
 				common->password = (gchar*) text;
 			}
 			// Remove user & password from URL
-			if (urifull.authority != urifull.host) {
-				memmove ((char*) urifull.authority, (char*) urifull.host,
-						strlen (urifull.host) + 1);
+			if (uuri.authority != uuri.host) {
+				memmove ((char*)uuri.uri + uuri.authority, (char*)uuri.uri + uuri.host,
+						strlen (uuri.uri + uuri.host) + 1);
 			}
 		}
 	}
 
 	// ------------------------------------------
-	// UgDataHttp
-	http = ug_dataset_realloc (dataset, UG_DATA_HTTP_I, 0);
+	// UgetHttp
+	http = ug_dataset_realloc (dataset, UgetHttpInfo, 0);
 	// referrer
 	text = gtk_entry_get_text ((GtkEntry*) dform->referrer_entry);
 	ug_str_set (&http->referrer, text, -1);
@@ -562,9 +562,9 @@ void	ug_download_form_get  (UgDownloadForm* dform, UgDataset* dataset)
 	ug_str_set (&http->user_agent, text, -1);
 
 	// ------------------------------------------
-	// UgRelation
+	// UgetRelation
 	if (gtk_widget_get_sensitive (dform->radio_pause)) {
-		relation = ug_dataset_realloc (dataset, UG_RELATION_I, 0);
+		relation = ug_dataset_realloc (dataset, UgetRelationInfo, 0);
 		if (gtk_toggle_button_get_active ((GtkToggleButton*) dform->radio_pause))
 			relation->hints |=  UG_HINT_PAUSED;
 		else
@@ -574,17 +574,17 @@ void	ug_download_form_get  (UgDownloadForm* dform, UgDataset* dataset)
 
 void	ug_download_form_set (UgDownloadForm* dform, UgDataset* dataset, gboolean keep_changed)
 {
-	UgDataCommon*	common;
-	UgDataHttp*		http;
-	UgRelation*		relation;
+	UgetCommon*	common;
+	UgetHttp*		http;
+	UgetRelation*		relation;
 
-	common = ug_dataset_realloc (dataset, UG_DATA_COMMON_I, 0);
-	http   = ug_dataset_get (dataset, UG_DATA_HTTP_I, 0);
+	common = ug_dataset_realloc (dataset, UgetCommonInfo, 0);
+	http   = ug_dataset_get (dataset, UgetHttpInfo, 0);
 
 	// disable changed flags
 	dform->changed.enable = FALSE;
 	// ------------------------------------------
-	// UgDataCommon
+	// UgetCommon
 	// set changed flags
 	if (keep_changed==FALSE && common) {
 		dform->changed.url      = common->keeping.url;
@@ -597,6 +597,7 @@ void	ug_download_form_set (UgDownloadForm* dform, UgDataset* dataset, gboolean k
 		dform->changed.delay    = common->keeping.retry_delay;
 		dform->changed.max_upload_speed   = common->keeping.max_upload_speed;
 		dform->changed.max_download_speed = common->keeping.max_download_speed;
+		dform->changed.retrieve_timestamp = common->keeping.retrieve_timestamp;
 	}
 	// set data
 	if (keep_changed==FALSE || dform->changed.url==FALSE) {
@@ -656,11 +657,11 @@ void	ug_download_form_set (UgDownloadForm* dform, UgDataset* dataset, gboolean k
 		gtk_spin_button_set_value ((GtkSpinButton*) dform->spin_connections,
 			common->max_connections);
 	}
-	if (keep_changed==FALSE || dform->changed.timestamp==FALSE)
+	if (keep_changed==FALSE || dform->changed.retrieve_timestamp==FALSE)
 		gtk_toggle_button_set_active (dform->timestamp, common->retrieve_timestamp);
 
 	// ------------------------------------------
-	// UgDataHttp
+	// UgetHttp
 	// set data
 	if (keep_changed==FALSE || dform->changed.referrer==FALSE) {
 		gtk_entry_set_text ((GtkEntry*) dform->referrer_entry,
@@ -687,9 +688,9 @@ void	ug_download_form_set (UgDownloadForm* dform, UgDataset* dataset, gboolean k
 	}
 
 	// ------------------------------------------
-	// UgRelation
+	// UgetRelation
 	if (gtk_widget_get_sensitive (dform->radio_pause)) {
-		relation = ug_dataset_realloc (dataset, UG_RELATION_I, 0);
+		relation = ug_dataset_realloc (dataset, UgetRelationInfo, 0);
 		if (relation->hints & UG_HINT_PAUSED)
 			gtk_toggle_button_set_active ((GtkToggleButton*) dform->radio_pause, TRUE);
 		else
@@ -784,22 +785,22 @@ void	ug_download_form_get_folder_list (UgDownloadForm* dform, GList** folder_lis
 
 void	ug_download_form_complete_entry (UgDownloadForm* dform)
 {
-	UgUriFull		urifull;
-	const gchar*	text;
-//	gchar*			temp;
-	gboolean		completed;
+	const gchar*  text;
+//	gchar*    temp;
+	UgUri     upart;
+	gboolean  completed;
 
 	// URL
 	text = gtk_entry_get_text ((GtkEntry*) dform->url_entry);
-	ug_uri_full_init (&urifull, text);
-	if (urifull.host) {
+	ug_uri_init (&upart, text);
+	if (upart.host) {
 		// disable changed flags
 		dform->changed.enable = FALSE;
 /*
 		// complete file entry
 		text = gtk_entry_get_text ((GtkEntry*) dform->file_entry);
 		if (text[0] == 0 || dform->changed.file == FALSE) {
-			temp = ug_uri_full_get_file (&urifull);
+			temp = ug_uri_get_file (&upart);
 			gtk_entry_set_text ((GtkEntry*) dform->file_entry,
 					(temp) ? temp : "index.htm");
 			g_free (temp);
@@ -807,7 +808,7 @@ void	ug_download_form_complete_entry (UgDownloadForm* dform)
 		// complete user entry
 		text = gtk_entry_get_text ((GtkEntry*) dform->username_entry);
 		if (text[0] == 0 || dform->changed.user == FALSE) {
-			temp = ug_uri_full_get_user (&urifull);
+			temp = ug_uri_get_user (&upart);
 			gtk_entry_set_text ((GtkEntry*) dform->username_entry,
 					(temp) ? temp : "");
 			g_free (temp);
@@ -815,7 +816,7 @@ void	ug_download_form_complete_entry (UgDownloadForm* dform)
 		// complete password entry
 		text = gtk_entry_get_text ((GtkEntry*) dform->password_entry);
 		if (text[0] == 0 || dform->changed.password == FALSE) {
-			temp = ug_uri_full_get_password (&urifull);
+			temp = ug_uri_get_password (&upart);
 			gtk_entry_set_text ((GtkEntry*) dform->password_entry,
 					(temp) ? temp : "");
 			g_free (temp);
