@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2013 by C.H. Huang
+ *   Copyright (C) 2005-2014 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@
  */
 
 #include <UgProxyForm.h>
-#include <UgData-download.h>
+#include <UgetData.h>
 #include <UgString.h>
 
 #include <glib/gi18n.h>
@@ -64,15 +64,15 @@ void	ug_proxy_form_init (UgProxyForm* pform)
 	widget = gtk_label_new (_("Proxy:"));
 	pform->type = gtk_combo_box_text_new ();
 	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (pform->type),
-			UG_DATA_PROXY_NONE, _("Don't use"));
+			UGET_PROXY_NONE, _("Don't use"));
 	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (pform->type),
-			UG_DATA_PROXY_DEFAULT, _("Default"));
+			UGET_PROXY_DEFAULT, _("Default"));
 	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (pform->type),
-			UG_DATA_PROXY_HTTP, "HTTP");
+			UGET_PROXY_HTTP, "HTTP");
 	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (pform->type),
-			UG_DATA_PROXY_SOCKS4, "SOCKS v4");
+			UGET_PROXY_SOCKS4, "SOCKS v4");
 	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (pform->type),
-			UG_DATA_PROXY_SOCKS5, "SOCKS v5");
+			UGET_PROXY_SOCKS5, "SOCKS v5");
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 1);
 	gtk_box_pack_start (GTK_BOX (hbox), pform->type, FALSE, FALSE, 2);
@@ -87,7 +87,7 @@ void	ug_proxy_form_init (UgProxyForm* pform)
 
 #ifdef HAVE_LIBPWMD
 	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (pform->type),
-			UG_DATA_PROXY_PWMD, "PWMD");
+			UGET_PROXY_PWMD, "PWMD");
 
 	ug_proxy_form_pwmd_init (&pform->pwmd, pform);
 	gtk_box_pack_end (GTK_BOX (vbox), pform->pwmd.self, TRUE, TRUE, 0);
@@ -177,11 +177,11 @@ static void	ug_proxy_form_std_init (UgProxyForm* pform)
 
 void	ug_proxy_form_get  (UgProxyForm* pform, UgDataset* dataset)
 {
-	UgDataProxy*	proxy;
+	UgetProxy*	proxy;
 	gint			index;
 
 	index = gtk_combo_box_get_active ((GtkComboBox*) pform->type);
-	proxy = ug_dataset_realloc (dataset, UG_DATA_PROXY_I, 0);
+	proxy = ug_dataset_realloc (dataset, UgetProxyInfo, 0);
 	proxy->type = index;
 
 	ug_str_set (&proxy->user,     gtk_entry_get_text ((GtkEntry*)pform->user), -1);
@@ -191,6 +191,7 @@ void	ug_proxy_form_get  (UgProxyForm* pform, UgDataset* dataset)
 
 #ifdef HAVE_LIBPWMD
 	ug_str_set (&proxy->pwmd.socket,  gtk_entry_get_text ((GtkEntry*)pform->pwmd.socket),  -1);
+	ug_str_set (&proxy->pwmd.socket_args,  gtk_entry_get_text ((GtkEntry*)pform->pwmd.socket_args),  -1);
 	ug_str_set (&proxy->pwmd.file,    gtk_entry_get_text ((GtkEntry*)pform->pwmd.file),    -1);
 	ug_str_set (&proxy->pwmd.element, gtk_entry_get_text ((GtkEntry*)pform->pwmd.element), -1);
 #endif	// HAVE_LIBPWMD
@@ -198,16 +199,16 @@ void	ug_proxy_form_get  (UgProxyForm* pform, UgDataset* dataset)
 
 void	ug_proxy_form_set  (UgProxyForm* pform, UgDataset* dataset, gboolean keep_changed)
 {
-	UgDataProxy*	proxy;
+	UgetProxy*	proxy;
 
-	proxy = ug_dataset_get (dataset, UG_DATA_PROXY_I, 0);
+	proxy = ug_dataset_get (dataset, UgetProxyInfo, 0);
 	// if no proxy data
 	if (proxy == NULL) {
 		pform->changed.enable = FALSE;	// disable changed flags
 		if (keep_changed == FALSE  ||  pform->changed.type == FALSE)
 			gtk_spin_button_set_value ((GtkSpinButton*) pform->port, 80);
 		if (keep_changed == FALSE  ||  pform->changed.port == FALSE)
-			gtk_combo_box_set_active ((GtkComboBox*) pform->type, UG_DATA_PROXY_NONE);
+			gtk_combo_box_set_active ((GtkComboBox*) pform->type, UGET_PROXY_NONE);
 		pform->changed.enable = TRUE;	// enable changed flags
 		return;
 	}
@@ -247,6 +248,7 @@ void	ug_proxy_form_set  (UgProxyForm* pform, UgDataset* dataset, gboolean keep_c
 #ifdef HAVE_LIBPWMD
 	if (keep_changed == FALSE) {
 		pform->pwmd.changed.socket  = proxy->pwmd.keeping.socket;
+		pform->pwmd.changed.socket_args  = proxy->pwmd.keeping.socket_args;
 		pform->pwmd.changed.file    = proxy->pwmd.keeping.file;
 		pform->pwmd.changed.element = proxy->pwmd.keeping.element;
 	}
@@ -255,6 +257,10 @@ void	ug_proxy_form_set  (UgProxyForm* pform, UgDataset* dataset, gboolean keep_c
 		gtk_entry_set_text ((GtkEntry*) pform->pwmd.socket,
 				(proxy->pwmd.socket) ? proxy->pwmd.socket: "");
 	}
+	if (keep_changed == FALSE  ||  pform->pwmd.changed.socket_args == FALSE) {
+		gtk_entry_set_text ((GtkEntry*) pform->pwmd.socket_args,
+				(proxy->pwmd.socket_args) ? proxy->pwmd.socket_args: "");
+	}
 	if (keep_changed == FALSE  ||  pform->pwmd.changed.file == FALSE) {
 		gtk_entry_set_text ((GtkEntry*) pform->pwmd.file,
 			    (proxy->pwmd.file) ? proxy->pwmd.file: "");
@@ -279,7 +285,7 @@ static void on_type_changed (GtkComboBox* widget, UgProxyForm* pform)
 	if (pform->changed.enable)
 		pform->changed.type = TRUE;
 	index = gtk_combo_box_get_active (widget);
-	if (index == UG_DATA_PROXY_NONE)
+	if (index == UGET_PROXY_NONE)
 		sensitive = FALSE;
 	else
 		sensitive = TRUE;
@@ -289,7 +295,7 @@ static void on_type_changed (GtkComboBox* widget, UgProxyForm* pform)
 #ifdef HAVE_LIBPWMD
 	gtk_widget_set_sensitive (pform->pwmd.self, sensitive);
 
-	if (index == UG_DATA_PROXY_PWMD) {
+	if (index == UGET_PROXY_PWMD) {
 		gtk_widget_set_visible (pform->std, FALSE);
 		gtk_widget_set_visible (pform->pwmd.self, TRUE);
 	}
@@ -334,21 +340,17 @@ static void	ug_proxy_form_pwmd_init (struct UgProxyFormPwmd* pfp, UgProxyForm* p
 	g_object_set (widget, "margin-top", 1, "margin-bottom", 1, NULL);
 	g_object_set (pfp->socket, "margin", 1, "hexpand", TRUE, NULL);
 	gtk_grid_attach (grid, widget, 0, 0, 1, 1);
-	gtk_grid_attach (grid, pfp->socket, 1, 0, 1, 1);
+	gtk_grid_attach (grid, pfp->socket, 1, 0, 4, 1);
 
-	widget = gtk_label_new_with_mnemonic (_("File:"));
-	pfp->file = gtk_entry_new ();
-	gtk_entry_set_width_chars (GTK_ENTRY (pfp->file), 16);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (widget), pfp->file);
+	widget = gtk_label_new_with_mnemonic (_("Socket args:"));
+	pfp->socket_args = gtk_entry_new ();
+	gtk_entry_set_width_chars (GTK_ENTRY (pfp->socket_args), 16);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (widget), pfp->socket_args);
 	g_object_set (widget, "margin-left", 3, "margin-right", 3, NULL);
 	g_object_set (widget, "margin-top", 1, "margin-bottom", 1, NULL);
-	g_object_set (pfp->file, "margin", 1, "hexpand", TRUE, NULL);
+	g_object_set (pfp->socket_args, "margin", 1, "hexpand", TRUE, NULL);
 	gtk_grid_attach (grid, widget, 0, 1, 1, 1);
-	gtk_grid_attach (grid, pfp->file, 1, 1, 1, 1);
-
-	widget = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
-	g_object_set (widget, "margin", 1, NULL);
-	gtk_grid_attach (grid, widget, 2, 0, 1, 2);
+	gtk_grid_attach (grid, pfp->socket_args, 1, 1, 4, 1);
 
 	widget = gtk_label_new_with_mnemonic (_("Element:"));
 	pfp->element = gtk_entry_new ();
@@ -357,11 +359,27 @@ static void	ug_proxy_form_pwmd_init (struct UgProxyFormPwmd* pfp, UgProxyForm* p
 	g_object_set (widget, "margin-left", 3, "margin-right", 3, NULL);
 	g_object_set (widget, "margin-top", 1, "margin-bottom", 1, NULL);
 	g_object_set (pfp->element, "margin", 1, "hexpand", TRUE, NULL);
-	gtk_grid_attach (grid, widget, 3, 0, 1, 1);
-	gtk_grid_attach (grid, pfp->element, 4, 0, 1, 1);
+	gtk_grid_attach (grid, widget, 3, 2, 1, 1);
+	gtk_grid_attach (grid, pfp->element, 4, 2, 1, 1);
+
+	widget = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
+	g_object_set (widget, "margin", 1, NULL);
+	gtk_grid_attach (grid, widget, 2, 2, 1, 2);
+
+	widget = gtk_label_new_with_mnemonic (_("File:"));
+	pfp->file = gtk_entry_new ();
+	gtk_entry_set_width_chars (GTK_ENTRY (pfp->file), 16);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (widget), pfp->file);
+	g_object_set (widget, "margin-left", 3, "margin-right", 3, NULL);
+	g_object_set (widget, "margin-top", 1, "margin-bottom", 1, NULL);
+	g_object_set (pfp->file, "margin", 1, "hexpand", TRUE, NULL);
+	gtk_grid_attach (grid, widget, 0, 2, 1, 1);
+	gtk_grid_attach (grid, pfp->file, 1, 2, 1, 1);
 
 	g_signal_connect (GTK_EDITABLE (pform->pwmd.socket), "changed",
 			G_CALLBACK (on_entry_pwmd_changed), pform);
+	g_signal_connect (GTK_EDITABLE (pform->pwmd.socket_args), "changed",
+			G_CALLBACK (on_entry_pwmd_changed), pform);
 	g_signal_connect (GTK_EDITABLE (pform->pwmd.file), "changed",
 			G_CALLBACK (on_entry_pwmd_changed), pform);
 	g_signal_connect (GTK_EDITABLE (pform->pwmd.element), "changed",
@@ -376,6 +394,8 @@ static void on_entry_pwmd_changed (GtkEditable* editable, UgProxyForm* pform)
 	if (pform->changed.enable) {
 		if (editable == GTK_EDITABLE (pform->pwmd.socket))
 			pform->pwmd.changed.socket = TRUE;
+		else if (editable == GTK_EDITABLE (pform->pwmd.socket_args))
+			pform->pwmd.changed.socket_args = TRUE;
 		else if (editable == GTK_EDITABLE (pform->pwmd.file))
 			pform->pwmd.changed.file = TRUE;
 		else if (editable == GTK_EDITABLE (pform->pwmd.element))
