@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2013 by C.H. Huang
+ *   Copyright (C) 2005-2014 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -88,12 +88,14 @@ struct UgProxyForm
 		GtkWidget*		self;
 
 		GtkWidget*		socket;
+	        GtkWidget*		socket_args;
 		GtkWidget*		file;
 		GtkWidget*		element;
 
 		// User changed entry
 		struct UgProxyFormPwmdChanged {
 			gboolean		socket:1;
+		        gboolean		socket_args:1;
 			gboolean		file:1;
 			gboolean		element:1;
 		} changed;
