@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2013 by C.H. Huang
+ *   Copyright (C) 2005-2014 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@
  */
 
 #include <UgDataset.h>
-#include <UgData-download.h>
+#include <UgetData.h>
 #include <UgSelector.h>
 #include <UgUri.h>
 #include <UgSetting.h>		// UG_APP_GTK_NAME
@@ -177,7 +177,7 @@ GList*	ug_selector_get_marked_downloads (UgSelector* selector)
 {
 	UgSelectorItem*	item;
 	UgDataset*		dataset;
-	UgDataCommon*	common;
+	UgetCommon*	common;
 	GString*		gstr;
 	GList*			list;
 	GList*			link;
@@ -211,7 +211,7 @@ GList*	ug_selector_get_marked_downloads (UgSelector* selector)
 		else
 			gstr = g_string_new (item->uri);
 		dataset = ug_dataset_new ();
-		common = ug_dataset_realloc (dataset, UG_DATA_COMMON_I, 0);
+		common = ug_dataset_realloc (dataset, UgetCommonInfo, 0);
 		common->url = g_string_free (gstr, FALSE);
 		common->keeping.url = TRUE;
 		link->data = dataset;
@@ -582,7 +582,7 @@ static void	ug_selector_page_add_filter (UgSelectorPage* page, GtkListStore* fil
 
 void	ug_selector_page_make_filter (UgSelectorPage* page)
 {
-	UgUriPart*		upart;
+	UgUri*		upart;
 	UgSelectorItem*	item;
 	GtkTreeModel*	model;
 	GtkTreeIter		iter;
@@ -592,15 +592,15 @@ void	ug_selector_page_make_filter (UgSelectorPage* page)
 	if (g_hash_table_size (page->filter.hash))
 		return;
 
-	upart = g_slice_alloc (sizeof (UgUriPart));
+	upart = g_slice_alloc (sizeof (UgUri));
 	model = GTK_TREE_MODEL (page->store);
 	value = gtk_tree_model_get_iter_first (model, &iter);
 	while (value) {
 		gtk_tree_model_get (model, &iter, 0, &item, -1);
 		// create filter by host ----------------
-		ug_uri_part_init (upart, item->uri);
+		ug_uri_init (upart, item->uri);
 		if (upart->authority)
-			key = g_strndup (item->uri, upart->path - item->uri);
+			key = g_strndup (item->uri, upart->path);
 		else
 			key = g_strdup ("(none)");
 		ug_selector_page_add_filter (page, page->filter.host, key, item);
@@ -614,7 +614,7 @@ void	ug_selector_page_make_filter (UgSelectorPage* page)
 		// next
 		value = gtk_tree_model_iter_next (model, &iter);
 	}
-	g_slice_free1 (sizeof (UgUriPart), upart);
+	g_slice_free1 (sizeof (UgUri), upart);
 }
 
 static void	ug_selector_page_mark_by_filter (UgSelectorPage* page, GtkListStore* filter_store)
