@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2013 by C.H. Huang
+ *   Copyright (C) 2005-2014 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -110,7 +110,7 @@ enum Aria2Status
 };
 
 // static data for UgPluginInterface
-static const char*	supported_schemes[]   = {"http", "https", "ftp", "ftps", NULL};
+static const char*	supported_schemes[]   = {"http", "https", "ftp", "magnet", NULL};
 static const char*	supported_filetypes[] = {"torrent", "metalink", "meta4", NULL};
 static char*		xmlrpc_uri;
 // extern
@@ -164,12 +164,12 @@ static UgResult	ug_plugin_aria2_global_set (guint parameter, gpointer data)
 
 static gboolean	ug_plugin_aria2_init (UgPluginAria2* plugin, UgDataset* dataset)
 {
-	UgDataCommon*	common;
-	UgDataHttp*		http;
+	UgetCommon*	common;
+	UgetHttp*		http;
 
 	// get data
-	common = ug_dataset_get (dataset, UG_DATA_COMMON_I, 0);
-	http   = ug_dataset_get (dataset, UG_DATA_HTTP_I, 0);
+	common = ug_dataset_get (dataset, UgetCommonInfo, 0);
+	http   = ug_dataset_get (dataset, UgetHttpInfo, 0);
 	// check data
 	if (common == NULL)
 		return FALSE;
@@ -179,10 +179,10 @@ static gboolean	ug_plugin_aria2_init (UgPluginAria2* plugin, UgDataset* dataset)
 	if (http)
 		http->redirection_count = 0;
 	// copy supported data
-	plugin->common = ug_datalist_copy (ug_dataset_get (dataset, UG_DATA_COMMON_I, 0));
-	plugin->proxy  = ug_datalist_copy (ug_dataset_get (dataset, UG_DATA_PROXY_I, 0));
-	plugin->http   = ug_datalist_copy (ug_dataset_get (dataset, UG_DATA_HTTP_I, 0));
-	plugin->ftp    = ug_datalist_copy (ug_dataset_get (dataset, UG_DATA_FTP_I, 0));
+	plugin->common = ug_datalist_copy (ug_dataset_get (dataset, UgetCommonInfo, 0));
+	plugin->proxy  = ug_datalist_copy (ug_dataset_get (dataset, UgetProxyInfo, 0));
+	plugin->http   = ug_datalist_copy (ug_dataset_get (dataset, UgetHttpInfo, 0));
+	plugin->ftp    = ug_datalist_copy (ug_dataset_get (dataset, UgetFtpInfo, 0));
 	// xmlrpc
 	ug_xmlrpc_init (&plugin->xmlrpc);
 	ug_xmlrpc_use_client (&plugin->xmlrpc, xmlrpc_uri, NULL);
@@ -212,17 +212,24 @@ static void	ug_plugin_aria2_finalize (UgPluginAria2* plugin)
 static UgResult	ug_plugin_aria2_set_state (UgPluginAria2* plugin, UgState  state)
 {
 	UgState		old_state;
+	GThread*    thread;
 
-	old_state		= plugin->state;
-	plugin->state	= state;
+	old_state = plugin->state;
 	// change plug-in status
 	if (state != old_state) {
 		if (state == UG_STATE_ACTIVE && old_state < UG_STATE_ACTIVE) {
 			// call ug_plugin_unref () by ug_plugin_aria2_thread ()
 			ug_plugin_ref ((UgPlugin*) plugin);
-			g_thread_new ("uget-aria2", (GThreadFunc) ug_plugin_aria2_thread, plugin);
+			// create thread
+			thread = g_thread_try_new ("uget-aria2",
+					(GThreadFunc) ug_plugin_aria2_thread, plugin, NULL);
+			if (thread == NULL) {
+				ug_plugin_unref ((UgPlugin*) plugin);
+				return UG_RESULT_ERROR;
+			}
+			g_thread_unref (thread);
 		}
-
+		plugin->state = state;
 		ug_plugin_post ((UgPlugin*) plugin, ug_message_new_state (state));
 	}
 
@@ -272,11 +279,11 @@ UgResult	ug_plugin_aria2_set (UgPluginAria2* plugin, guint parameter, gpointer d
 
 static UgResult	ug_plugin_aria2_get (UgPluginAria2* plugin, guint parameter, gpointer data)
 {
-	UgProgress*	progress;
+	UgetProgress*	progress;
 
 	if (parameter != UG_TYPE_INSTANCE)
 		return UG_RESULT_UNSUPPORT;
-	if (data == NULL || ((UgData*)data)->iface != UG_PROGRESS_I)
+	if (data == NULL || ((UgData*)data)->iface != UgetProgressInfo)
 		return UG_RESULT_UNSUPPORT;
 
 	progress = data;
@@ -308,7 +315,7 @@ static UgResult	ug_plugin_aria2_get (UgPluginAria2* plugin, guint parameter, gpo
 //
 static gpointer	ug_plugin_aria2_thread (UgPluginAria2* plugin)
 {
-	UgDataCommon*	common;
+	UgetCommon*	common;
 	UgMessage*		message;
 	char*			string;
 	const char*		temp;
@@ -464,7 +471,7 @@ static gboolean	ug_plugin_aria2_add_uri	(UgPluginAria2* plugin)
 	UgXmlrpcValue*		uris;		// UG_XMLRPC_ARRAY
 	UgXmlrpcValue*		options;	// UG_XMLRPC_STRUCT
 	UgXmlrpcValue*		value;
-	UgDataCommon*		common;
+	UgetCommon*			common;
 	UgXmlrpcResponse	response;
 	char*				curr;
 	char*				prev;
@@ -477,7 +484,7 @@ static gboolean	ug_plugin_aria2_add_uri	(UgPluginAria2* plugin)
 	value->type = UG_XMLRPC_STRING;
 	value->c.string = common->url;
 	// URIs array (mirrors)
-	for (curr = common->mirrors;  curr && curr[0];  curr = curr + 1) {
+	for (curr = common->mirrors;  curr && curr[0];) {
 		// skip space ' '
 		while (curr[0] == ' ')
 			curr++;
@@ -986,13 +993,13 @@ static void	ug_plugin_aria2_post_error (UgPluginAria2* plugin, int code)
 //
 static void	ug_plugin_aria2_set_scheme (UgPluginAria2* plugin)
 {
-	UgDataCommon*	common;
-	UgDataHttp*		http;
-	UgDataFtp*		ftp;
-	UgUriFull*		uri;
-	GString*		str_uri;
-	gchar*			user;
-	gchar*			password;
+	UgetCommon* common;
+	UgetHttp*   http;
+	UgetFtp*    ftp;
+	UgUri*      uuri;
+	GString*    str_uri;
+	gchar*      user;
+	gchar*      password;
 
 	common = plugin->common;
 	http   = plugin->http;
@@ -1021,27 +1028,27 @@ static void	ug_plugin_aria2_set_scheme (UgPluginAria2* plugin)
 	}
 
 	if (user) {
-		uri = g_slice_new (UgUriFull);
-		ug_uri_full_init (uri, common->url);
-		if (uri->authority) {
+		uuri = g_slice_new (UgUri);
+		ug_uri_init (uuri, common->url);
+		if (uuri->authority) {
 			str_uri = g_string_sized_new (100);
-			g_string_append_len (str_uri, common->url, uri->authority - common->url);
+			g_string_append_len (str_uri, common->url, uuri->authority);
 			g_string_append (str_uri, user);
 			g_string_append_c (str_uri, ':');
 			g_string_append (str_uri, password);
 			g_string_append_c (str_uri, '@');
-			g_string_append (str_uri, uri->host);
+			g_string_append (str_uri, uuri->uri + uuri->host);
 			g_free (common->url);
 			common->url = g_string_free (str_uri, FALSE);
 		}
-		g_slice_free (UgUriFull, uri);
+		g_slice_free (UgUri, uuri);
 	}
 }
 
 static void	ug_plugin_aria2_set_common	(UgPluginAria2* plugin, UgXmlrpcValue* options)
 {
 	UgXmlrpcValue*	value;
-	UgDataCommon*	common;
+	UgetCommon*		common;
 	GString*		string;
 
 	common = plugin->common;
@@ -1117,7 +1124,7 @@ static void	ug_plugin_aria2_set_common	(UgPluginAria2* plugin, UgXmlrpcValue* op
 static void	ug_plugin_aria2_set_http (UgPluginAria2* plugin, UgXmlrpcValue* options)
 {
 	UgXmlrpcValue*	value;
-	UgDataHttp*		http;
+	UgetHttp*		http;
 
 	http = plugin->http;
 
@@ -1146,14 +1153,14 @@ static void	ug_plugin_aria2_set_http (UgPluginAria2* plugin, UgXmlrpcValue* opti
 static gboolean	ug_plugin_aria2_set_proxy (UgPluginAria2* plugin, UgXmlrpcValue* options)
 {
 	UgXmlrpcValue*	value;
-	UgDataProxy*	proxy;
+	UgetProxy*	proxy;
 
 	proxy = plugin->proxy;
 	if (proxy == NULL)
 		return TRUE;
 
 #ifdef HAVE_LIBPWMD
-	if (proxy->type == UG_DATA_PROXY_PWMD) {
+	if (proxy->type == UGET_PROXY_PWMD) {
 		if (ug_plugin_aria2_set_proxy_pwmd (plugin, options) == FALSE)
 			return FALSE;
 	}
@@ -1241,7 +1248,7 @@ static gboolean	ug_plugin_aria2_set_proxy_pwmd (UgPluginAria2 *plugin, UgXmlrpcV
 
 fail:
        ug_close_pwmd(&pwmd);
-       gchar *e = g_strdup_printf("Pwmd ERR %i: %s", rc, pwmd_strerror(rc));
+       gchar *e = g_strdup_printf("Pwmd ERR %i: %s", rc, gpg_strerror(rc));
        message = ug_message_new_error (UG_MESSAGE_ERROR_CUSTOM, e);
        ug_plugin_post ((UgPlugin*) plugin, message);
        fprintf(stderr, "%s\n", e);
