@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2013 by C.H. Huang
+ *   Copyright (C) 2005-2014 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -42,7 +42,7 @@
 
 #include <string.h>
 #include <UgPlugin-curl.h>
-#include <UgData-download.h>
+#include <UgetData.h>
 #include <UgStdio.h>
 #include <UgUtils.h>
 #include <UgString.h>
@@ -91,7 +91,7 @@ static UgResult	ug_plugin_curl_get			(UgPluginCurl* plugin, guint parameter, gpo
 
 // thread and setup functions
 static gpointer	ug_plugin_curl_thread		(UgPluginCurl* plugin);
-static gboolean	ug_plugin_curl_open_file	(UgPluginCurl* plugin, UgDataCommon* common);
+static gboolean	ug_plugin_curl_open_file	(UgPluginCurl* plugin, UgetCommon* common);
 static void		ug_plugin_curl_set_scheme	(UgPluginCurl* plugin, CURL* curl);
 static void		ug_plugin_curl_set_proxy	(UgPluginCurl* plugin, CURL* curl);
 
@@ -140,11 +140,11 @@ static void	ug_plugin_curl_global_finalize (void)
 
 static gboolean	ug_plugin_curl_init (UgPluginCurl* plugin, UgDataset* dataset)
 {
-	UgDataCommon*	common;
-	UgDataHttp*		http;
+	UgetCommon*	common;
+	UgetHttp*		http;
 
-	common = ug_dataset_get (dataset, UG_DATA_COMMON_I, 0);
-	http   = ug_dataset_get (dataset, UG_DATA_HTTP_I, 0);
+	common = ug_dataset_get (dataset, UgetCommonInfo, 0);
+	http   = ug_dataset_get (dataset, UgetHttpInfo, 0);
 	// check data
 	if (common == NULL  ||  common->url == NULL)
 		return FALSE;
@@ -154,10 +154,10 @@ static gboolean	ug_plugin_curl_init (UgPluginCurl* plugin, UgDataset* dataset)
 	if (http)
 		http->redirection_count = 0;
 	// copy supported data
-	plugin->common = ug_datalist_copy (ug_dataset_get (dataset, UG_DATA_COMMON_I, 0));
-	plugin->proxy  = ug_datalist_copy (ug_dataset_get (dataset, UG_DATA_PROXY_I, 0));
-	plugin->http   = ug_datalist_copy (ug_dataset_get (dataset, UG_DATA_HTTP_I, 0));
-	plugin->ftp    = ug_datalist_copy (ug_dataset_get (dataset, UG_DATA_FTP_I, 0));
+	plugin->common = ug_datalist_copy (ug_dataset_get (dataset, UgetCommonInfo, 0));
+	plugin->proxy  = ug_datalist_copy (ug_dataset_get (dataset, UgetProxyInfo, 0));
+	plugin->http   = ug_datalist_copy (ug_dataset_get (dataset, UgetHttpInfo, 0));
+	plugin->ftp    = ug_datalist_copy (ug_dataset_get (dataset, UgetFtpInfo, 0));
 
 	// default values
 	plugin->resumable = TRUE;
@@ -180,17 +180,25 @@ static void	ug_plugin_curl_finalize (UgPluginCurl* plugin)
 
 static UgResult	ug_plugin_curl_set_state (UgPluginCurl* plugin, UgState  state)
 {
-	UgState		old_state;
+	UgState  old_state;
+	GThread* thread;
 
-	old_state		= plugin->state;
-	plugin->state	= state;
+	old_state = plugin->state;
 	// change plug-in status
 	if (state != old_state) {
 		if (state == UG_STATE_ACTIVE && old_state < UG_STATE_ACTIVE) {
-			ug_plugin_ref ((UgPlugin*) plugin);		// call ug_plugin_unref () by ug_plugin_curl_thread ()
-			g_thread_new ("uget-curl", (GThreadFunc) ug_plugin_curl_thread, plugin);
+			// call ug_plugin_unref () by ug_plugin_curl_thread ()
+			ug_plugin_ref ((UgPlugin*) plugin);
+			// create thread
+			thread = g_thread_try_new ("uget-curl",
+					(GThreadFunc) ug_plugin_curl_thread, plugin, NULL);
+			if (thread == NULL) {
+				ug_plugin_unref ((UgPlugin*) plugin);
+				return UG_RESULT_ERROR;
+			}
+			g_thread_unref (thread);
 		}
-
+		plugin->state = state;
 		ug_plugin_post ((UgPlugin*) plugin, ug_message_new_state (state));
 	}
 
@@ -223,14 +231,14 @@ static UgResult	ug_plugin_curl_set (UgPluginCurl* plugin, guint parameter, gpoin
 
 static UgResult	ug_plugin_curl_get (UgPluginCurl* plugin, guint parameter, gpointer data)
 {
-	UgProgress*	progress;
+	UgetProgress*	progress;
 	gdouble		complete;
 	gdouble		total;
 	gdouble		speed;
 
 	if (parameter != UG_TYPE_INSTANCE)
 		return UG_RESULT_UNSUPPORT;
-	if (data == NULL || ((UgData*)data)->iface != UG_PROGRESS_I)
+	if (data == NULL || ((UgData*)data)->iface != UgetProgressInfo)
 		return UG_RESULT_UNSUPPORT;
 
 	progress = data;
@@ -267,10 +275,10 @@ static gpointer	ug_plugin_curl_thread (UgPluginCurl* plugin)
 	CURLcode		curl_code;
 	long			curl_time;
 	long			response_code;
-	UgDataCommon*	common;
-	UgDataProxy*	proxy;
-	UgDataHttp*		http;
-	UgDataFtp*		ftp;
+	UgetCommon*	common;
+	UgetProxy*	proxy;
+	UgetHttp*		http;
+	UgetFtp*		ftp;
 
 	// supported data
 	common = plugin->common;
@@ -283,7 +291,7 @@ static gpointer	ug_plugin_curl_thread (UgPluginCurl* plugin)
 
 	// Common option ----------------------------------------------------------
 	curl_easy_setopt (curl, CURLOPT_URL, common->url);
-	curl_easy_setopt (curl, CURLOPT_NOSIGNAL, 1);
+	curl_easy_setopt (curl, CURLOPT_NOSIGNAL, 1L);
 	// setup scheme and it's related data (user & password)
 	ug_plugin_curl_set_scheme (plugin, curl);
 	// check filename
@@ -308,29 +316,29 @@ static gpointer	ug_plugin_curl_thread (UgPluginCurl* plugin)
 	if (proxy) {
 		// proxy type
 		switch (proxy->type) {
-		case UG_DATA_PROXY_NONE:
+		case UGET_PROXY_NONE:
 			curl_easy_setopt (curl, CURLOPT_PROXYTYPE, 0);
 			break;
 
 		default:
-		case UG_DATA_PROXY_DEFAULT:
-		case UG_DATA_PROXY_HTTP:
+		case UGET_PROXY_DEFAULT:
+		case UGET_PROXY_HTTP:
 			curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_HTTP);
 			ug_plugin_curl_set_proxy (plugin, curl);
 			break;
 
-		case UG_DATA_PROXY_SOCKS4:
+		case UGET_PROXY_SOCKS4:
 			curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_SOCKS4);
 			ug_plugin_curl_set_proxy (plugin, curl);
 			break;
 
-		case UG_DATA_PROXY_SOCKS5:
+		case UGET_PROXY_SOCKS5:
 			curl_easy_setopt (curl, CURLOPT_PROXYTYPE, CURLPROXY_SOCKS5);
 			ug_plugin_curl_set_proxy (plugin, curl);
 			break;
 
 #ifdef HAVE_LIBPWMD
-		case UG_DATA_PROXY_PWMD:
+		case UGET_PROXY_PWMD:
 			if (ug_plugin_curl_set_proxy_pwmd (plugin) == FALSE)
 				goto exit;
 			break;
@@ -340,9 +348,9 @@ static gpointer	ug_plugin_curl_thread (UgPluginCurl* plugin)
 
 	// HTTP option ------------------------------------------------------------
 	// use libcurl's redirection.
-  	curl_easy_setopt (curl, CURLOPT_FOLLOWLOCATION, 1);
-	curl_easy_setopt (curl, CURLOPT_AUTOREFERER, 1);
-	curl_easy_setopt (curl, CURLOPT_MAXREDIRS, 30);
+  	curl_easy_setopt (curl, CURLOPT_FOLLOWLOCATION, 1L);
+	curl_easy_setopt (curl, CURLOPT_AUTOREFERER, 1L);
+	curl_easy_setopt (curl, CURLOPT_MAXREDIRS, 30L);
 
 	if (http) {
 		if (http->referrer == NULL)
@@ -415,7 +423,7 @@ static gpointer	ug_plugin_curl_thread (UgPluginCurl* plugin)
 	curl_easy_setopt (curl, CURLOPT_NOPROGRESS, FALSE);
 
 	// Others -----------------------------------------------------------------
-	curl_easy_setopt (curl, CURLOPT_FILETIME, 1);	// use with CURLINFO_FILETIME
+	curl_easy_setopt (curl, CURLOPT_FILETIME, 1L);	// use with CURLINFO_FILETIME
 	curl_easy_setopt (curl, CURLOPT_SSL_VERIFYPEER, FALSE);	// disable peer SSL certificate verification
 	curl_easy_setopt (curl, CURLOPT_ERRORBUFFER, plugin->curl_error_string);
 	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_LIMIT, 100);
@@ -596,12 +604,12 @@ exit:
 
 	if (plugin->state == UG_STATE_ACTIVE)
 		ug_plugin_curl_set_state (plugin, UG_STATE_READY);
-	ug_plugin_unref ((UgPlugin*) plugin);	// call ug_plugin_ref () by ug_plugin_curl_set_state ()
-
+	// call ug_plugin_ref () by ug_plugin_curl_set_state ()
+	ug_plugin_unref ((UgPlugin*) plugin);
 	return NULL;
 }
 
-static gboolean	ug_plugin_curl_open_file (UgPluginCurl* plugin, UgDataCommon* common)
+static gboolean	ug_plugin_curl_open_file (UgPluginCurl* plugin, UgetCommon* common)
 {
 	if (plugin->file_stream == NULL) {
 		g_free (plugin->path);
@@ -648,9 +656,9 @@ static gboolean	ug_plugin_curl_open_file (UgPluginCurl* plugin, UgDataCommon* co
 // setup scheme and it's related data (user & password)
 static void	ug_plugin_curl_set_scheme (UgPluginCurl* plugin, CURL* curl)
 {
-	UgDataCommon*	common;
-	UgDataHttp*		http;
-	UgDataFtp*		ftp;
+	UgetCommon*	common;
+	UgetHttp*		http;
+	UgetFtp*		ftp;
 
 	common = plugin->common;
 	http   = plugin->http;
@@ -699,7 +707,7 @@ static void	ug_plugin_curl_set_scheme (UgPluginCurl* plugin, CURL* curl)
 
 static void	ug_plugin_curl_set_proxy (UgPluginCurl* plugin, CURL* curl)
 {
-	UgDataProxy*	proxy;
+	UgetProxy*	proxy;
 
 	proxy = plugin->proxy;
 	curl_easy_setopt (curl, CURLOPT_PROXY, proxy->host);
@@ -710,8 +718,8 @@ static void	ug_plugin_curl_set_proxy (UgPluginCurl* plugin, CURL* curl)
 		curl_easy_setopt (curl, CURLOPT_PROXYPORT, 80);
 	// proxy user and password
 	if (proxy->user || proxy->password ||
-		proxy->type == UG_DATA_PROXY_SOCKS4 ||
-		proxy->type == UG_DATA_PROXY_SOCKS5)
+		proxy->type == UGET_PROXY_SOCKS4 ||
+		proxy->type == UGET_PROXY_SOCKS5)
 	{
 		curl_easy_setopt (curl, CURLOPT_PROXYUSERNAME,
 				(proxy->user)     ? proxy->user     : "");
@@ -752,7 +760,7 @@ static int  ug_plugin_curl_progress (UgPluginCurl* plugin,
 // the HTTP headers are case-insensitive supposed to be according to RFC 2616.
 static size_t	ug_plugin_curl_header_http (char *buffer, size_t size, size_t nmemb, UgPluginCurl *plugin)
 {
-	UgDataCommon*	common;
+	UgetCommon*	common;
 	gchar*			file;
 	gchar*			temp;
 
@@ -888,7 +896,7 @@ static gboolean	ug_plugin_curl_set_proxy_pwmd (UgPluginCurl *plugin)
 
 fail:
        ug_close_pwmd(&pwmd);
-       gchar *e = g_strdup_printf("Pwmd ERR %i: %s", rc, pwmd_strerror(rc));
+       gchar *e = g_strdup_printf("Pwmd ERR %i: %s", rc, gpg_strerror(rc));
        message = ug_message_new_error (UG_MESSAGE_ERROR_CUSTOM, e);
        ug_plugin_post ((UgPlugin*) plugin, message);
        fprintf(stderr, "%s\n", e);
