@@ -1,6 +1,6 @@
 /*
  *
- *   Copyright (C) 2005-2013 by C.H. Huang
+ *   Copyright (C) 2005-2014 by C.H. Huang
  *   plushuang.tw@gmail.com
  *
  *  This library is free software; you can redistribute it and/or
@@ -100,9 +100,10 @@ const char*	ug_io_channel_decide_encoding (GIOChannel* channel);
 // ------------------------------------------------------------------
 // others
 //
+gboolean	ug_launch_uri (const gchar* uri);
 gboolean	ug_launch_default_app (const gchar* folder, const gchar* file);
 void		ug_shutdown (void);
-
+gchar*		ug_sys_release (void);
 
 #ifdef __cplusplus
 }
